Cloning a Starter Project
-------------------------

All new Steamship packages and plugins begin with the command ``ship create``.

If you haven't done so already, install our CLI by running the following command in your terminal (you'll need `NPM`_):

.. code-block:: bash

   npm install -g @steamship/cli

Then make sure you're authenticated by typing:

.. code-block:: bash

   ship login

Once you're up and running, create a new project by typing

.. code-block:: bash

   ship create

Our CLI will walk you through a menu of options that will help you select the kind starter project that best fits your goals.

.. _NPM: http://npmjs.com/
